Generates a dataset of transaction records that tracks how the case estimates
of the total incurred, the outstanding claim payments, and the cumulative
claims paid change over time. A sample dataset is included as part of the
package, see test_incurred_dataset.
generate_incurred_dataset(claims, incurred_history)A dataframe that takes the same structure as
test_incurred_dataset.
an claims object containing all the simulated quantities,
(other than those related to incurred loss), see
claims.
the full history of incurred case estimates, see
claim_history.
test_incurred_dataset